import os
import cv2
import numpy as np
import tensorflow as tf
import matplotlib.pyplot as plt

# Chemin vers le dossier contenant les images à tester
image_folder_path = '/home/pi/test_02/'

# Charger le modèle sauvegardé
model = tf.keras.models.load_model('cat_classifier_model.keras')

# Liste des images dans le dossier
image_files = [f for f in os.listdir(image_folder_path) if f.endswith('.jpg')]

# Parcourir chaque image et faire une prédiction
for image_file in image_files:
    image_path = os.path.join(image_folder_path, image_file)
    image = cv2.imread(image_path)

    if image is None:
        print(f"Erreur : Impossible de charger l'image {image_file}.")
        continue
    
    # Redimensionner l'image à 128x128 pixels
    resized_image = cv2.resize(image, (128, 128))

    # Normaliser les valeurs des pixels
    normalized_image = resized_image / 255.0

    # Adapter la forme de l'image pour correspondre à celle attendue par le modèle
    input_image = normalized_image.reshape(1, 128, 128, 3)

    # Faire une prédiction
    prediction = model.predict(input_image)
    predicted_class = 'chat' if prediction[0] < 0.5 else 'chien'

    print(f'Image: {image_file} - Le modèle prédit que l\'image est : {predicted_class}')

    # Afficher l'image pour vérification visuelle et attendre l'entrée de l'utilisateur
    plt.imshow(cv2.cvtColor(resized_image, cv2.COLOR_BGR2RGB))
    plt.title(f'Prédiction : {predicted_class}')
    plt.show()
    input("Appuyez sur Entrée pour passer à l'image suivante...")
